@@ -7,16 +7,20 @@ use swc_ecma_utils::{
     alias_ident_for, is_rest_arguments, prepend, private_ident, quote_ident, ExprFactory, IdentExt,
 };
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut, VisitMutWith};
+use swc_trace_macro::swc_trace;
 
 struct ObjectSuper {
     extra_vars: Vec<Ident>,
 }
+
+#[tracing::instrument(level = "trace", skip_all)]
 pub fn object_super() -> impl Fold + VisitMut {
     as_folder(ObjectSuper {
         extra_vars: Vec::new(),
     })
 }
 
+#[swc_trace]
 impl VisitMut for ObjectSuper {
     noop_visit_mut_type!();
 
@@ -123,6 +127,8 @@ struct SuperReplacer {
     obj: Option<Ident>,
     vars: Vec<Ident>,
 }
+
+#[swc_trace]
 impl VisitMut for SuperReplacer {
     noop_visit_mut_type!();
 
@@ -145,6 +151,7 @@ impl VisitMut for SuperReplacer {
     }
 }
 
+#[swc_trace]
 impl SuperReplacer {
     fn get_obj_ref(&mut self) -> Ident {
         if let Some(obj) = &self.obj {
@@ -602,7 +609,7 @@ mod tests {
             b(){
                 let inner = {
                     d:function d(){
-                        super.d() // should not transform 
+                        super.d() // should not transform
                     }
                 }
             },
