@@ -2,13 +2,16 @@ use swc_common::DUMMY_SP;
 use swc_ecma_ast::*;
 use swc_ecma_utils::{IdentExt, IsDirective};
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut};
+use swc_trace_macro::swc_trace;
 
+#[tracing::instrument(level = "trace", skip_all)]
 pub fn export_namespace_from() -> impl Fold + VisitMut {
     as_folder(ExportNamespaceFrom)
 }
 
 struct ExportNamespaceFrom;
 
+#[swc_trace]
 impl VisitMut for ExportNamespaceFrom {
     noop_visit_mut_type!();
 
