@@ -1,8 +1,9 @@
+var _foo = new WeakMap();
 let Foo = function() {
     "use strict";
     function Foo() {
         _classCallCheck(this, Foo);
-        _foo.set(this, {
+        _classPrivateFieldInit(this, _foo, {
             writable: true,
             value: 1
         });
@@ -11,10 +12,11 @@ let Foo = function() {
         {
             key: "test",
             value: function test() {
+                var _foo1 = new WeakMap();
                 let Nested = function() {
                     function Nested() {
                         _classCallCheck(this, Nested);
-                        _foo1.set(this, {
+                        _classPrivateFieldInit(this, _foo1, {
                             writable: true,
                             value: 2
                         });
@@ -29,11 +31,9 @@ let Foo = function() {
                     ]);
                     return Nested;
                 }();
-                var _foo1 = new WeakMap();
                 _foo.has(this);
             }
         }
     ]);
     return Foo;
 }();
-var _foo = new WeakMap();
